# Generated by Django 3.2.7 on 2021-10-17 21:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('workspaces', '0005_auto_20211017_2104'),
    ]

    operations = [
        migrations.AddField(
            model_name='environmentconfig',
            name='workspace',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='workspaces.workspace'),
        ),
        migrations.AlterUniqueTogether(
            name='environmentconfig',
            unique_together={('key', 'workspace')},
        ),
    ]
