# Generated by Django 3.2.7 on 2021-12-02 21:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('generic_groups', '0006_alter_genericgroup_workspace'),
        ('files', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='file',
            name='generic_groups',
            field=models.ManyToManyField(blank=True, to='generic_groups.GenericGroup'),
        ),
    ]
