# Generated by Django 3.2.7 on 2021-10-17 21:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('authorization', '0003_auto_20211017_2031'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='permission',
            name='workspace',
        ),
        migrations.RemoveField(
            model_name='role',
            name='workspace',
        ),
    ]
