# Generated by Django 3.2.7 on 2021-10-18 00:50

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('generic_groups', '0005_genericgroup_workspace'),
        ('authorization', '0005_auto_20211017_2105'),
        ('users', '0007_auto_20211018_0049'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserRoleGenericGroup',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='generic_groups.genericgroup')),
                ('role', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='authorization.role')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'unique_together': {('user', 'group', 'role')},
            },
        ),
    ]
