# Generated by Django 3.2.7 on 2021-12-15 16:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('settings', '0003_settings_generic_groups'),
    ]

    operations = [
        migrations.AddField(
            model_name='settings',
            name='disabled',
            field=models.BooleanField(default=False),
        ),
    ]
