# Generated by Django 3.2.7 on 2021-12-06 01:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workspaces', '0011_auto_20211206_0106'),
    ]

    operations = [
        migrations.AlterField(
            model_name='workspace',
            name='name',
            field=models.CharField(blank=True, default='', max_length=258),
        ),
    ]
