# Generated by Django 3.2.7 on 2021-12-06 13:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0020_delete_usersviewset'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='phone_number',
            field=models.CharField(blank=True, default=None, max_length=20, null=True),
        ),
    ]
