# Generated by Django 3.2.7 on 2021-12-15 16:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('generic_groups', '0006_alter_genericgroup_workspace'),
    ]

    operations = [
        migrations.AddField(
            model_name='genericgroup',
            name='disabled',
            field=models.BooleanField(default=False),
        ),
    ]
