# Generated by Django 3.2.7 on 2021-11-21 19:07

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('generic_groups', '0006_alter_genericgroup_workspace'),
        ('workspaces', '0009_alter_workspace_slug'),
        ('users', '0015_auto_20211118_2214'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='workspace',
        ),
        migrations.RemoveField(
            model_name='user',
            name='workspace_roles',
        ),
        migrations.AlterField(
            model_name='userroleworkspace',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='user_role_workspaces', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterUniqueTogether(
            name='userrolegenericgroup',
            unique_together={('user', 'group')},
        ),
        migrations.AlterUniqueTogether(
            name='userroleworkspace',
            unique_together={('user', 'workspace')},
        ),
    ]
