# Generated by Django 3.2.7 on 2021-10-17 22:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workspaces', '0007_delete_environmentconfig'),
    ]

    operations = [
        migrations.AlterField(
            model_name='workspace',
            name='db_connection',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
