# Generated by Django 3.2.7 on 2021-10-17 21:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('workspaces', '0006_auto_20211017_2105'),
    ]

    operations = [
        migrations.DeleteModel(
            name='EnvironmentConfig',
        ),
    ]
