# Generated by Django 3.2.7 on 2021-10-17 21:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0003_rename_related_workspace_user_workspace'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='workspace',
        ),
    ]
