# Generated by Django 3.2.7 on 2021-10-17 20:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('workspaces', '0003_auto_20211017_2031'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='workspace',
            name='id',
        ),
        migrations.AlterField(
            model_name='workspace',
            name='slug',
            field=models.CharField(max_length=50, primary_key=True, serialize=False, unique=True),
        ),
    ]
