# Generated by Django 3.2.7 on 2021-10-17 17:13

from django.db import migrations, models
import django_extensions.db.fields
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='GenericGroup',
            fields=[
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('label', models.CharField(max_length=255)),
                ('generic_groups', models.ManyToManyField(blank=True, to='generic_groups.GenericGroup')),
            ],
            options={
                'verbose_name': 'Generic group',
                'verbose_name_plural': 'Generic groups',
            },
        ),
    ]
