# Generated by Django 3.2.7 on 2021-12-02 21:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0019_user_has_overmind_access'),
    ]

    operations = [
        migrations.DeleteModel(
            name='UsersViewSet',
        ),
    ]
