# Generated by Django 3.2.7 on 2021-11-24 16:08

from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields
import munity.files.models
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('workspaces', '0009_alter_workspace_slug'),
    ]

    operations = [
        migrations.CreateModel(
            name='File',
            fields=[
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.CharField(blank=True, max_length=255)),
                ('type', models.CharField(blank=True, max_length=32)),
                ('size', models.BigIntegerField(blank=True)),
                ('file', models.FileField(upload_to=munity.files.models.generate_filename)),
                ('workspace', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='workspaces.workspace')),
            ],
            options={
                'ordering': ('-created',),
            },
        ),
    ]
