# Generated by Django 3.2.7 on 2021-12-02 12:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('records', '0009_auto_20211202_1229'),
    ]

    operations = [
        migrations.AlterField(
            model_name='record',
            name='diff_value',
            field=models.JSONField(null=True),
        ),
        migrations.AlterField(
            model_name='record',
            name='previous_value',
            field=models.JSONField(null=True),
        ),
    ]
