# Generated by Django 3.2.7 on 2021-10-19 09:04

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('workspaces', '0008_alter_workspace_db_connection'),
        ('authorization', '0005_auto_20211017_2105'),
    ]

    operations = [
        migrations.AlterField(
            model_name='permission',
            name='workspace',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='workspaces.workspace'),
        ),
        migrations.AlterField(
            model_name='role',
            name='workspace',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='workspaces.workspace'),
        ),
    ]
