# Generated by Django 3.2.7 on 2021-10-19 17:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0011_user_testt'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='testt',
        ),
    ]
