# Generated by Django 3.2.7 on 2021-12-02 17:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('workspaces', '0009_alter_workspace_slug'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='workspace',
            options={'ordering': ('slug',)},
        ),
    ]
