# Generated by Django 3.2.7 on 2021-12-02 17:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0018_user_avatar'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='has_overmind_access',
            field=models.BooleanField(blank=True, default=False),
        ),
    ]
